@@ -15,6 +15,8 @@
 # You should have received a copy of the GNU General Public License
 # along with icd. If not, see <http:#www.gnu.org/licenses/>.
 
+#nocov start
+
 rtf_year_ok <- function(year) {
   !is.null(rtf_fetch_year(year, offline = TRUE))
 }
@@ -68,10 +70,10 @@ skip_flat_icd9_avail_all <- function() {
 expect_equal_no_icd <- function(object, expected, ...) {
   class(object) <- class(object)[class(object) %nin% icd_all_classes]
   class(expected) <- class(expected)[class(expected) %nin% icd_all_classes]
-  # may wrap wtih eval and bquote, but this can fail mysteriously
   testthat::expect_equivalent(object, expected, ...)
 }
 
+#' @keywords internal debugging
 expect_equal_no_class_order <- function(object, expected, ...) {
   eval(bquote(testthat::expect_true(all(class(.(object)) %in% class(.(expected))), ...)))
   eval(bquote(testthat::expect_equivalent(unclass(.(object)), unclass(.(expected)), ...)))
@@ -87,7 +89,7 @@ expect_equal_no_class_order <- function(object, expected, ...) {
 #' @param end ICD code
 #' @param ver_chaps list with each member being a start-end pair, and names
 #'   being the chapter names
-#' @param ... arguments passed to \code{\link[testthat]{expect_true}}
+#' @param ... arguments passed to \code{expect_true} in 'testthat' package
 #' @keywords internal debugging
 expect_chap_equal <- function(x, start, end, ver_chaps, ...) {
   x <- tolower(x)
@@ -95,7 +97,6 @@ expect_chap_equal <- function(x, start, end, ver_chaps, ...) {
   # new testthat doesn't return a result object, but TRUE
   if (!isTRUE(res) || (is.list(res) && !res$passed))
     return(res)
-
   eval(bquote(testthat::expect_equal(.(ver_chaps[[which(tolower(names(ver_chaps)) == x)]]),
                                      c(start = .(start), end = .(end)), ...)))
 }
@@ -106,7 +107,7 @@ expect_icd10_sub_chap_equal <- function(x, start, end, ...) {
 }
 
 expect_explain_equal <- function(x, desc, ...) {
-  eval(bquote(expect_equal(icd_explain(.(x)), .(desc), ...)))
+  eval(bquote(expect_equal(explain(.(x)), .(desc), ...)))
 }
 
 
@@ -229,11 +230,11 @@ expect_icd10_only_sub_chap <- function(x, ...) {
 
 }
 
-#' @describeIn icd_classes_ordered \code{testthat} \code{expect} function
+#' @describeIn classes_ordered \code{testthat} \code{expect} function
 #'   for ICD classes to be in correct order.
 #' @keywords internal debugging
-expect_icd_classes_ordered <- function(x) {
-  eval(bquote(testthat::expect_true(icd_classes_ordered(.(x)))))
+expect_classes_ordered <- function(x) {
+  eval(bquote(testthat::expect_true(classes_ordered(.(x)))))
 }
 
 #' generate random ICD-9 codes
@@ -254,7 +255,7 @@ generate_random_short_icd10cm_bill <- function(n = 10, short_code = TRUE) {
   if (short_code)
     x
   else
-    icd_short_to_decimal(x)
+    short_to_decimal(x)
 }
 
 #' @rdname generate_random_short_icd9
@@ -262,7 +263,7 @@ generate_random_short_icd10cm_bill <- function(n = 10, short_code = TRUE) {
 generate_random_decimal_icd9 <- function(n = 50000)
   paste(
     round(stats::runif(min = 1, max = 999, n = n)),
-    sample(icd_expand_minor.icd9(""), replace = TRUE, size = n),
+    sample(expand_minor.icd9(""), replace = TRUE, size = n),
     sep = "."
   )
 
@@ -287,7 +288,7 @@ generate_random_unordered_pts <- function(num_patients = 50000, dz_per_patient =
   set.seed(1441)
   pts <- round(n / np)
   data.frame(
-    visit_id = sample(seq(1, pts), replace = TRUE, size = n),
+    visit_id = as_char_no_warn(sample(seq(1, pts), replace = TRUE, size = n)),
     code = fun(n),
     poa = as.factor(
       sample(x = c("Y", "N", "n", "n", "y", "X", "E", "", NA),
@@ -315,3 +316,12 @@ random_string <- function(n, max_chars = 4) {
          FUN.VALUE = character(n)
   )  %>% apply(1, paste0, collapse = "")
 }
+
+#' allow microbenchmark to compare multiple results
+#' @param x list of values to compare for identity, e.g. results from evaluated
+#'   expression in \code{microbenchmark::microbenchmark}
+#' @keywords internal
+all_identical <- function(x)
+  all(sapply(x[-1], function(y) identical(x[[1]], y)))
+
+#nocov end
