@@ -19,10 +19,10 @@ knitr::opts_chunk$set(
 uranium_pathology[1:10, ]
 
 ## ----uranium-wide--------------------------------------------------------
-uranium_pathology %>% icd_long_to_wide %>% head
+uranium_pathology %>% long_to_wide %>% head
 
 ## ----comorbidities-------------------------------------------------------
-quan_comorbidities <- icd_comorbid(uranium_pathology, icd10_map_quan_elix)
+quan_comorbidities <- comorbid(uranium_pathology, icd10_map_quan_elix)
 # see the first few rows and columns:
 quan_comorbidities[1:6, 3:10]
 
@@ -30,7 +30,7 @@ quan_comorbidities[1:6, 3:10]
 # create trivial comorbidity map:
 cholera_typhoid_map <- list(cholera = "A00", typhoid = "A01")
 patients <- data.frame(patient = c("0001", "0001", "0002"), code = c("A001234567", "A01", "A019"))
-icd_comorbid(patients , map = cholera_typhoid_map)
+comorbid(patients , map = cholera_typhoid_map)
 
 ## ----htncx---------------------------------------------------------------
 icd10_map_quan_elix$HTNcx
