@@ -1,4 +1,4 @@
-// Copyright (C) 2014 - 2017  Jack O. Wasey
+// Copyright (C) 2014 - 2018  Jack O. Wasey
 //
 // This file is part of icd.
 //
@@ -18,7 +18,8 @@
 #ifndef GUESS_H_
 #define GUESS_H_
 
-#include "local.h"
+#include "config.h"
+#include "icd_types.h"
 #include <Rcpp.h>
 #include <vector>
 #include <string>
