@@ -18,12 +18,11 @@
 #ifndef MANIP_ALT_H_
 #define MANIP_ALT_H_
 
-// [[Rcpp::interfaces(r, cpp)]]
 #include <Rcpp.h>
 #include "Rcpp/String.h"  // for String
 #include "icd_types.h"    // for CV
 
-Rcpp::String icd9AddLeadingZeroesShortSingle(Rcpp::String x);
-CV icd9AddLeadingZeroesDirect(CV x, bool short_code);
+Rcpp::String icd9AddLeadingZeroes_alt_ShortSingle(Rcpp::String x);
+CV icd9AddLeadingZeroes_alt_Direct(CV x, bool short_code);
 
 #endif /* MANIP_ALT_H_ */
