@@ -15,64 +15,38 @@
 // You should have received a copy of the GNU General Public License
 // along with icd. If not, see <http://www.gnu.org/licenses/>.
 
-// [[Rcpp::interfaces(r, cpp)]]
-#include <Rcpp/r/headers.h>             // for Rf_install
+#include "icd_types.h"                  // for VecStr, CV, Str
+#include <Rcpp.h>
 #include <algorithm>                    // for set_intersection
 #include <iterator>                     // for insert_iterator, inserter
 #include <set>                          // for _Rb_tree_const_iterator, set
 #include <vector>                       // for vector, vector<>::const_iterator
-#include "Rcpp.h"                       // for wrap
-#include "Rcpp/Environment.h"           // for Environment
-#include "Rcpp/api/meat/Environment.h"  // for Environment_Impl::Environment...
-#include "Rcpp/api/meat/proxy.h"        // for AttributeProxyPolicy::Attribu...
-#include "Rcpp/as.h"                    // for as
-#include "Rcpp/proxy/AttributeProxy.h"  // for AttributeProxyPolicy<>::Attri...
-#include "Rcpp/proxy/Binding.h"         // for BindingPolicy<>::const_Binding
-#include "Rcpp/vector/Vector.h"         // for Vector<>::iterator, Vector<>:...
-#include "Rcpp/vector/instantiation.h"  // for List
-#include "Rcpp/vector/proxy.h"          // for r_vector_name_proxy<>::type
-#include "Rcpp/vector/string_proxy.h"   // for string_proxy
-#include "RcppCommon.h"                 // for Proxy_Iterator
-#include "appendMinor.h"                // for icd9MajMinToShortSingleStd
+#include "appendMinor_alt.h"           // for icd9MajMinToShortSingle_alt_Std
 #include "convert.h"                    // for icd9ShortToPartsCpp
-#include "convert_alt.h"                // for icd9ShortToPartsCppStd
-#include "icd_types.h"                  // for VecStr, CV, Str
+#include "convert_alt.h"                // for icd9ShortToParts_alt_Cpp
 #include "is.h"                         // for icd9IsASingleE
-#include "local.h"                      // for icd_set
-#include "ranges.h"                     // for icd9ExpandMinorStd
+#include "ranges_alt.h"                     // for icd9ExpandMinor_alt_Std
 
 //' Find child codes from vector of ICD-9 codes.
 //'
 //' Pure C++11 implementation using \code{unordered set} to find children of
 //' given codes
-//' @examples
-//' if (requireNamespace("microbenchmark")) {
-//' microbenchmark::microbenchmark(
-//'   icd:::icd9ChildrenShort(c("001", 100:500), onlyReal = TRUE),
-//'   icd:::icd9ChildrenShort11(c("001", 100:500), onlyReal = TRUE),
-//'   times = 5)
-//'   # C++11 about 15% faster for this data
-//' }
 //' @keywords internal
 // [[Rcpp::export]]
-CV icd9ChildrenShort11(CV icd9Short, bool onlyReal) {
+CV icd9ChildrenShort_alt_11(CV icd9Short, bool onlyReal) {
   icd_set out; // we are never going to put NAs in the output?
   // this is a slower function, can the output set be predefined in size?
   if (icd9Short.size() != 0) {
     Rcpp::List parts = icd9ShortToPartsCpp(icd9Short, "");
     CV major = parts[0];
     CV minor = parts[1];
-
     CV::iterator itmajor = major.begin();
     CV::iterator itminor = minor.begin();
     for (; itmajor != major.end(); ++itmajor, ++itminor) {
       Str thismajor = Rcpp::as<Str>(*itmajor);
       Str thisminor = Rcpp::as<Str>(*itminor);
-
-      VecStr newminors = icd9ExpandMinorStd(thisminor, icd9IsASingleE(thismajor.c_str()));
-
-      VecStr newshort = icd9MajMinToShortSingleStd(thismajor, newminors);
-
+      VecStr newminors = icd9ExpandMinor_alt_Std(thisminor, icd9IsASingleE(thismajor.c_str()));
+      VecStr newshort = icd9MajMinToShortSingle_alt_Std(thismajor, newminors);
       out.insert(newshort.begin(), newshort.end());
     }
     if (onlyReal) {
@@ -95,42 +69,27 @@ CV icd9ChildrenShort11(CV icd9Short, bool onlyReal) {
 }
 
 //' C++ implementation of finding children of short codes
-//' @examples
-//' \dontrun{
-//' library(microbenchmark)
-//' microbenchmark(icd9ChildrenShort("001", T), icd9ChildrenShortStd("001", T), times = 100)
-//' microbenchmark(icd9ChildrenShort(c("001", 100:400), T),
-//'                icd9ChildrenShortUnordered(c("001", 100:400), T),
-//'                icd9ChildrenShortStd(c("001", 100:400), T),
-//'                times = 10)
-//' }
-//' # un-ordered set much faster, but may still need to sort result
 //' @keywords internal
 // [[Rcpp::export]]
-CV icd9ChildrenShortStd(CV icd9Short, bool onlyReal) {
+CV icd9ChildrenShort_alt_Std(CV icd9Short, bool onlyReal) {
   // set may be unordered_set if C++11 is available, so may have to reorder at end
-#ifdef HAVE_CXX11
   // http://www.cplusplus.com/reference/unordered_set/unordered_set/unordered_set/
   icd_set out(icd9Short.size()); // n is hash buckets, not items
-#else
-  icd_set out; // plain std::set does not have buckets, or possiblity of reserving space.
-#endif
-  // we are never going to put NAs in the output, so use std structure this is a
-  // slower function, can the output set be predefined in size?
-  if (icd9Short.size() != 0) {
-    VecStr major(icd9Short.size());
-    VecStr minor(icd9Short.size());
-    icd9ShortToPartsCppStd(Rcpp::as<VecStr>(icd9Short), "", major, minor);
 
-    VecStr::const_iterator itmajor = major.begin();
-    VecStr::const_iterator itminor = minor.begin();
-    for (; itmajor != major.end(); ++itmajor, ++itminor) {
+  // we are never going to put NAs in the output, so use std structure this is a
+
+  // This is a slower function, can the output set be predefined in size?
+  if (icd9Short.size() != 0) {
+    VecStr mjr(icd9Short.size());
+    VecStr mnr(icd9Short.size());
+    icd9ShortToParts_alt_CppStd(Rcpp::as<VecStr>(icd9Short), "", mjr, mnr);
+    VecStr::const_iterator itmajor = mjr.begin();
+    VecStr::const_iterator itminor = mnr.begin();
+    for (; itmajor != mjr.end(); ++itmajor, ++itminor) {
       Str thismajor = *itmajor;
       Str thisminor = *itminor;
-
-      VecStr newminors = icd9ExpandMinorStd(thisminor, icd9IsASingleE(thismajor.c_str()));
-      VecStr newshort = icd9MajMinToShortSingleStd(thismajor, newminors);
-
+      VecStr newminors = icd9ExpandMinor_alt_Std(thisminor, icd9IsASingleE(thismajor.c_str()));
+      VecStr newshort = icd9MajMinToShortSingle_alt_Std(thismajor, newminors);
       out.insert(newshort.begin(), newshort.end());
     }
 
@@ -141,16 +100,10 @@ CV icd9ChildrenShortStd(CV icd9Short, bool onlyReal) {
       VecStr tmp = Rcpp::as<VecStr>(icd9Hierarchy["code"]);
       // 'reals' is the set of all known, 'real' defined codes
       icd_set reals(tmp.begin(), tmp.end());
-#ifdef HAVE_CXX11
       for (icd_set::iterator j = out.begin(); j != out.end(); ++j) {
         if (reals.find(*j) != reals.end())
           out_real.insert(*j);
       }
-#else
-      std::set_intersection(out.begin(), out.end(),
-                            reals.begin(), reals.end(),
-                            std::inserter(out_real, out_real.begin()));
-#endif
       out = out_real;
     }
   } // input length != 0
@@ -158,3 +111,92 @@ CV icd9ChildrenShortStd(CV icd9Short, bool onlyReal) {
   rcppOut.attr("icd_short_diag") = true;
   return rcppOut;
 }
+
+// [[Rcpp::export]]
+VecStr icd9Children_alt_ShortNoNaUnordered(const VecStr& icd9Short, const bool onlyReal) {
+  icd_set out; // we are never going to put NAs in the output, so use std structure
+  // this is a slower function, can the output set be predefined in size?
+  VecStr mjr(icd9Short.size());
+  VecStr mnr(icd9Short.size());
+  if (icd9Short.size() != 0) {
+    icd9ShortToParts_alt_CppStd(icd9Short, "", mjr, mnr);
+
+    VecStr::iterator itmjr = mjr.begin();
+    VecStr::iterator itmnr = mnr.begin();
+    for (; itmjr != mjr.end(); ++itmjr, ++itmnr) {
+      const VecStr& newminors = icd9ExpandMinor_alt_Std(*itmnr, icd9IsASingleE((*itmjr).c_str()));
+      VecStr newshort = icd9MajMinToShortSingle_alt_Std(*itmjr, newminors);
+      out.insert(newshort.begin(), newshort.end());
+    }
+    if (onlyReal) {
+      const Rcpp::Environment env("package:icd");
+      Rcpp::List icd9Hierarchy = env["icd9cm_hierarchy"];
+      icd_set out_real;
+      VecStr tmp = Rcpp::as<VecStr >(
+        icd9Hierarchy["code"]);
+      // 'reals' is the set of majors, intermediate and leaf codes.
+      icd_set reals(tmp.begin(), tmp.end());
+
+      for (icd_set::iterator j = out.begin(); j != out.end(); ++j) {
+        if (reals.find(*j) != reals.end())
+          out_real.insert(*j);
+      }
+      out = out_real;
+    }
+  } // input length != 0
+  // TODO in R wrapper: rcppOut.attr("icd_short_diag") = true;
+  // sort from unordered set into a vector
+  VecStr out_vec(out.begin(), out.end());
+  return out_vec;
+}
+
+// [[Rcpp::export]]
+VecStr icd9ExpandMinor_alt_Std(const Str& mnr, bool isE) {
+  if (!isE) {
+    switch (mnr.size()) {
+    case 0:
+      return vv_std;
+    case 1:
+      switch (mnr[0]) { // use .at() for range check
+      case '0':
+        return v0_std;
+      case '1':
+        return v1_std;
+      case '2':
+        return v2_std;
+      case '3':
+        return v3_std;
+      case '4':
+        return v4_std;
+      case '5':
+        return v5_std;
+      case '6':
+        return v6_std;
+      case '7':
+        return v7_std;
+      case '8':
+        return v8_std;
+      case '9':
+        return v9_std;
+      default:
+        Rcpp::stop("unrecognized minor character");
+      return v_empty_std;
+      }
+    case 2:
+      return VecStr(1, mnr);
+    default:
+      Rcpp::stop("invalid minor in icd9ExpandMinor_alt_Std");
+    return v_empty_std;
+    }
+  } else {
+    // is E code, so minor must be just one character
+    switch (mnr.size()) {
+    case 0:
+      return vbase_e_std;
+    case 1:
+      return VecStr(1, mnr);
+    default:
+      Rcpp::stop("invalid E code minor in icd9ExpandMinor_alt_Std");
+    }
+  }
+}
