@@ -18,28 +18,28 @@
 context("filtering on POA")
 
 test_that("filter POA - not a data frame", {
-  expect_error(icd_filter_poa_no(list(pollo = "loco")))
+  expect_error(filter_poa_no(list(pollo = "loco")))
 })
 
 test_that("filter POA - no poa field", {
-  expect_error(icd_filter_poa_yes(simple_poa_pts[1:2]))
+  expect_error(filter_poa_yes(simple_poa_pts[1:2]))
 })
 
 test_that("filter POA - generic func - invalid poa type", {
-  expect_error(icd_filter_poa(x = simple_poa_pts,
+  expect_error(filter_poa(x = simple_poa_pts,
                              poaField = "poa", poa = "not an option"))
-  expect_error(icd_filter_poa(x = simple_poa_pts,
+  expect_error(filter_poa(x = simple_poa_pts,
                              poaField = "poa", poa = ""))
-  expect_error(icd_filter_poa(x = simple_poa_pts,
+  expect_error(filter_poa(x = simple_poa_pts,
                              poaField = "poa", poa = NA))
 })
 
 test_that("filter POA - wrong name poa field", {
   pd <- simple_poa_pts
   names(pd) <- c("visit_id", "icd9", "achilleus")
-  expect_error(icd_filter_poa_yes(pd, poaField = "poa"))
-  expect_error(icd_filter_poa_yes(pd, poaField = "odysseus"))
-  expect_error(icd_filter_poa_yes(pd))
+  expect_error(filter_poa_yes(pd, poaField = "poa"))
+  expect_error(filter_poa_yes(pd, poaField = "odysseus"))
+  expect_error(filter_poa_yes(pd))
 })
 
 test_that("filter POA - poa is factor", {
@@ -57,52 +57,52 @@ test_that("filter POA - poa is factor", {
   names(complex_poa_pts)[3] <- "poa"
 
   # row names are preserved here: probably not important, but a little annoying
-  expect_identical(icd_filter_poa_yes(simple_poa_pts),
+  expect_identical(filter_poa_yes(simple_poa_pts),
                    simple_poa_pts[1, 1:2])
-  expect_identical(icd_filter_poa_not_yes(simple_poa_pts),
+  expect_identical(filter_poa_not_yes(simple_poa_pts),
                    simple_poa_pts[-1, 1:2])
-  expect_identical(icd_filter_poa_no(simple_poa_pts),
+  expect_identical(filter_poa_no(simple_poa_pts),
                    simple_poa_pts[2, 1:2])
-  expect_identical(icd_filter_poa_not_no(simple_poa_pts),
+  expect_identical(filter_poa_not_no(simple_poa_pts),
                    simple_poa_pts[-2, 1:2])
 
-  expect_identical(icd_filter_poa_yes(complex_poa_pts),
+  expect_identical(filter_poa_yes(complex_poa_pts),
                    complex_poa_pts[1, 1:2])
-  expect_identical(icd_filter_poa_not_yes(complex_poa_pts),
+  expect_identical(filter_poa_not_yes(complex_poa_pts),
                    complex_poa_pts[-1, 1:2])
-  expect_identical(icd_filter_poa_no(complex_poa_pts),
+  expect_identical(filter_poa_no(complex_poa_pts),
                    complex_poa_pts[2, 1:2])
-  expect_identical(icd_filter_poa_not_no(complex_poa_pts),
+  expect_identical(filter_poa_not_no(complex_poa_pts),
                    complex_poa_pts[-2, 1:2])
 })
 
 test_that("filter POA - poa is vector", {
-  expect_identical(icd_filter_poa_yes(simple_poa_pts),
+  expect_identical(filter_poa_yes(simple_poa_pts),
                    simple_poa_pts[1, 1:2])
-  expect_identical(icd_filter_poa_not_yes(simple_poa_pts),
+  expect_identical(filter_poa_not_yes(simple_poa_pts),
                    simple_poa_pts[-1, 1:2])
-  expect_identical(icd_filter_poa_no(simple_poa_pts),
+  expect_identical(filter_poa_no(simple_poa_pts),
                    simple_poa_pts[2, 1:2])
-  expect_identical(icd_filter_poa_not_no(simple_poa_pts),
+  expect_identical(filter_poa_not_no(simple_poa_pts),
                    simple_poa_pts[-2, 1:2])
 
-  expect_identical(icd_filter_poa_yes(complex_poa_pts),
+  expect_identical(filter_poa_yes(complex_poa_pts),
                    complex_poa_pts[1, 1:2])
-  expect_identical(icd_filter_poa_not_yes(complex_poa_pts),
+  expect_identical(filter_poa_not_yes(complex_poa_pts),
                    complex_poa_pts[-1, 1:2])
-  expect_identical(icd_filter_poa_no(complex_poa_pts),
+  expect_identical(filter_poa_no(complex_poa_pts),
                    complex_poa_pts[2, 1:2])
-  expect_identical(icd_filter_poa_not_no(complex_poa_pts),
+  expect_identical(filter_poa_not_no(complex_poa_pts),
                    complex_poa_pts[-2, 1:2])
 
   # same via core function
-  expect_identical(icd_filter_poa(complex_poa_pts, poa = "yes"),
+  expect_identical(filter_poa(complex_poa_pts, poa = "yes"),
                    complex_poa_pts[1, 1:2])
-  expect_identical(icd_filter_poa(complex_poa_pts, poa = "notYes"),
+  expect_identical(filter_poa(complex_poa_pts, poa = "notYes"),
                    complex_poa_pts[-1, 1:2])
-  expect_identical(icd_filter_poa(complex_poa_pts, poa = "no"),
+  expect_identical(filter_poa(complex_poa_pts, poa = "no"),
                    complex_poa_pts[2, 1:2])
-  expect_identical(icd_filter_poa(complex_poa_pts, poa = "notNo"),
+  expect_identical(filter_poa(complex_poa_pts, poa = "notNo"),
                    complex_poa_pts[-2, 1:2])
 
 })
@@ -110,13 +110,13 @@ test_that("filter POA - poa is vector", {
 test_that("filter POA - poa upper and lower case", {
   smpl <- simple_poa_pts
   smpl[["poa"]] <- c("Y", "n", "e", NA)
-  expect_identical(icd_filter_poa_no(smpl), icd_filter_poa_no(simple_poa_pts))
+  expect_identical(filter_poa_no(smpl), filter_poa_no(simple_poa_pts))
 })
 
 test_that("filter POA - just Y and N should be complementary", {
   # take any data frame to start out:
   dfrm <- test_twenty;
   dfrm <- dfrm[dfrm[["poa"]] %in% c("Y", "N", "y", "n"), ]
-  expect_identical(icd_filter_poa_no(dfrm),  icd_filter_poa_not_yes(dfrm))
-  expect_identical(icd_filter_poa_yes(dfrm), icd_filter_poa_not_no(dfrm))
+  expect_identical(filter_poa_no(dfrm),  filter_poa_not_yes(dfrm))
+  expect_identical(filter_poa_yes(dfrm), filter_poa_not_no(dfrm))
 })
