@@ -19,8 +19,9 @@ if (requireNamespace("lintr", quietly = TRUE) &&
     "package:devtools" %nin% search()) {
   context("lints, if lintr available")
   test_that("there are no lints", {
+    skip("currently ignoring .lintr and spamming github")
     # running lints keeps failing after devtools load_all, but works fine with
     # fresh session
-    lintr::expect_lint_free()
+    lintr::expect_lint_free() # skip this - currently ignoring .lintr and spamming github.
   })
 }
